@@ -46,10 +46,10 @@ class Constants():
 	"""Package major version: '**2**' ( String )"""
 	minorVersion = "0"
 	"""Package minor version: '**0**' ( String )"""
-	changeVersion = "3"
-	"""Package change version: '**3**' ( String )"""
+	changeVersion = "4"
+	"""Package change version: '**4**' ( String )"""
 	releaseVersion = ".".join((majorVersion, minorVersion, changeVersion))
-	"""Package release version: '**2.0.3**' ( String )"""
+	"""Package release version: '**2.0.4**' ( String )"""
 
 	logger = "Foundations_Logger"
 	"""Package logger name: '**Foundations_Logger**' ( String )"""
@@ -62,12 +62,6 @@ class Constants():
 	loggingSeparators = "*" * 96
 	"""Logging separators: '*' * 96 ( String )"""
 
-	executionTraceArgumentMaximumLength = 255
-	"""Execution trace argument maximum length: '**255**' ( Integer )"""
-
-	excludeTaggedFramesFromStackTrace = True
-	"""Exclude tagged frames from stack trace: '**True**' ( Boolean )"""
-
 	encodingFormat = "utf-8"
 	"""Default encoding format: '**utf-8**' ( String )"""
 	encodingError = "ignore"
@@ -82,5 +76,5 @@ class Constants():
 		providerDirectory = ".HDRLabs"
 		"""Package provider directory: '**HDRLabs** on Windows / Darwin, **.HDRLabs** on Linux' ( String )"""
 
-	nullObject = "None"
+	nullObject = str(None)
 	"""Default null object string: '**None**' ( String )"""
