@@ -18,18 +18,16 @@
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
-import logging
 import re
 import weakref
 
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.core as core
 import foundations.dataStructures
 import foundations.exceptions
+import foundations.verbose
 import foundations.walkers
-from foundations.globals.constants import Constants
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -43,7 +41,7 @@ __status__ = "Production"
 
 __all__ = ["LOGGER", "Attribute", "AbstractNode", "AbstractCompositeNode"]
 
-LOGGER = logging.getLogger(Constants.logger)
+LOGGER = foundations.verbose.installLogger()
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
@@ -53,7 +51,6 @@ class Attribute(foundations.dataStructures.Structure):
 	This class represents a storage object for the :class:`AbstractNode` class attributes.
 	"""
 
-	@core.executionTrace
 	def __init__(self, name=None, value=None, **kwargs):
 		"""
 		This method initializes the class.
@@ -99,7 +96,7 @@ class Attribute(foundations.dataStructures.Structure):
 		return self.__name
 
 	@name.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def name(self, value):
 		"""
 		This method is the setter method for **self.__name** attribute.
@@ -110,7 +107,7 @@ class Attribute(foundations.dataStructures.Structure):
 		self.__name = value
 
 	@name.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def name(self):
 		"""
 		This method is the deleter method for **name** attribute.
@@ -130,7 +127,6 @@ class Attribute(foundations.dataStructures.Structure):
 		return self.__value
 
 	@value.setter
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def value(self, value):
 		"""
 		This method is the setter method for **self.__value** attribute.
@@ -141,7 +137,7 @@ class Attribute(foundations.dataStructures.Structure):
 		self.__value = value
 
 	@value.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def value(self):
 		"""
 		This method is the deleter method for **value** attribute.
@@ -153,7 +149,19 @@ class Attribute(foundations.dataStructures.Structure):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	# @core.executionTrace
+	def __hash__(self):
+		"""
+		This method reimplements the :meth:`foundations.dataStructures.Structure.__hash__` method.
+		
+		:return: Object hash. ( Integer )
+		
+		:note: :class:`foundations.dataStructures.Structure` inherits from **dict** and
+		should not be made hashable because of its mutability, however considering the fact the id
+		is used as the hash value, making the object hashable should be fairly safe. 
+		"""
+
+		return hash(id(self))
+
 	def __repr__(self):
 		"""
 		This method reimplements the :meth:`foundations.dataStructures.Structure.__repr__` method.
@@ -165,7 +173,7 @@ class Attribute(foundations.dataStructures.Structure):
 
 class AbstractNode(foundations.dataStructures.Structure):
 	"""
-	| This class defines the base node class.
+	| This class defines the base Node class.
 	| Although it can be instancied directly that class is meant to be subclassed.
 	
 	:note: This class doesn't provide compositing capabilities,
@@ -176,12 +184,11 @@ class AbstractNode(foundations.dataStructures.Structure):
 	"""Node family. ( String )"""
 
 	__instanceId = 1
-	"""Node id: Defines the next node instance identity number. ( Integer )"""
+	"""Node id: Defines the next Node instance identity number. ( Integer )"""
 
 	__nodesInstances = weakref.WeakValueDictionary()
-	"""Node instances: Each node, once instanced is stored in this attribute. ( Dictionary )"""
+	"""Nodes instances: Each node, once instanced is referenced in this attribute. ( Dictionary )"""
 
-	@core.executionTrace
 	def __new__(cls, *args, **kwargs):
 		"""
 		This method is the constructor of the class.
@@ -199,7 +206,6 @@ class AbstractNode(foundations.dataStructures.Structure):
 		AbstractNode._AbstractNode__instanceId += 1
 		return instance
 
-	@core.executionTrace
 	def __init__(self, name=None, **kwargs):
 		"""
 		This method initializes the class.
@@ -241,7 +247,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		return getattr(self, "_{0}__{1}".format(self.__class__.__name__, "family"))
 
 	@family.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def family(self, value):
 		"""
 		This method is the setter method for **self.__family** attribute.
@@ -253,7 +259,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "family"))
 
 	@family.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def family(self):
 		"""
 		This method is the deleter method for **self.__family** attribute.
@@ -273,7 +279,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		return self.__nodesInstances
 
 	@nodesInstances.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def nodesInstances(self, value):
 		"""
 		This method is the setter method for **self.__nodesInstances** attribute.
@@ -285,7 +291,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "nodesInstances"))
 
 	@nodesInstances.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def nodesInstances(self):
 		"""
 		This method is the deleter method for **self.__nodesInstances** attribute.
@@ -305,7 +311,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		return self.__identity
 
 	@identity.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def identity(self, value):
 		"""
 		This method is the setter method for **self.__identity** attribute.
@@ -317,7 +323,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "identity"))
 
 	@identity.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def identity(self):
 		"""
 		This method is the deleter method for **self.__identity** attribute.
@@ -337,7 +343,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		return self.__name
 
 	@name.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def name(self, value):
 		"""
 		This method is the setter method for **self.__name** attribute.
@@ -351,7 +357,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		self.__name = value
 
 	@name.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def name(self):
 		"""
 		This method is the deleter method for **self.__name** attribute.
@@ -363,7 +369,6 @@ class AbstractNode(foundations.dataStructures.Structure):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	# @core.executionTrace
 	def __repr__(self):
 		"""
 		This method reimplements the :meth:`foundations.dataStructures.Structure.__repr__` method.
@@ -373,38 +378,22 @@ class AbstractNode(foundations.dataStructures.Structure):
 
 		return "<{0} object at {1}>".format(self.__class__.__name__, hex(id(self)))
 
-	# @core.executionTrace
 	def __hash__(self):
 		"""
 		This method reimplements the :meth:`foundations.dataStructures.Structure.__hash__` method.
 		
 		:return: Object hash. ( Integer )
 		
-		:note: :class:`foundations.dataStructures.Structure` inherits from **dict** and should not be made hashable because of its mutability,
-		however considering the fact the unique node identity is used as the hash value,
-		making the object hashable should be safe. 
+		:note: :class:`foundations.dataStructures.Structure` inherits from **dict** and
+		should not be made hashable because of its mutability, however considering the fact the id
+		is used as the hash value, making the object hashable should be fairly safe. 
 		"""
 
-		return hash(self.__identity)
+		return hash(id(self))
 
-	@core.executionTrace
-	def __cmp__(self, other):
-		"""
-		This method reimplements the :meth:`foundations.dataStructures.Structure.__cmp__` method.
-		
-		:param other: Comparison node. ( AbstractNode )
-		:return: Comparison value. ( Integer )
-		"""
-
-		if type(other) == type(self):
-			return cmp(self.__identity, other.identity)
-		else:
-			raise TypeError("Unable to compare '{0}' and '{1}' objects.".format(self, other))
-
-	@core.executionTrace
 	def __getDefaultNodeName(self):
 		"""
-		This method gets the default node name.
+		This method gets the default Node name.
 		
 		:return: Node name. ( String )
 		"""
@@ -412,11 +401,9 @@ class AbstractNode(foundations.dataStructures.Structure):
 		return "{0}{1}".format(self.family, self.__identity)
 
 	@classmethod
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getNodeByIdentity(cls, identity):
 		"""
-		This method returns the node with given identity.
+		This method returns the Node with given identity.
 	
 		Usage::
 
@@ -432,11 +419,9 @@ class AbstractNode(foundations.dataStructures.Structure):
 
 		return cls.__nodesInstances.get(identity, None)
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def listAttributes(self):
 		"""
-		This method returns the node attributes names.
+		This method returns the Node attributes names.
 
 		Usage::
 
@@ -449,11 +434,9 @@ class AbstractNode(foundations.dataStructures.Structure):
 
 		return [attribute for attribute, value in self.iteritems() if issubclass(value.__class__, Attribute)]
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getAttributes(self):
 		"""
-		This method returns the node attributes.
+		This method returns the Node attributes.
 
 		Usage::
 
@@ -466,8 +449,6 @@ class AbstractNode(foundations.dataStructures.Structure):
 
 		return [attribute for attribute in self.itervalues() if issubclass(attribute.__class__, Attribute)]
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def attributeExists(self, name):
 		"""
 		This method returns if given attribute exists in the node.
@@ -489,8 +470,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 				return True
 		return False
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.NodeAttributeTypeError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.NodeAttributeTypeError)
 	def addAttribute(self, name, value):
 		"""
 		This method adds given attribute to the node.
@@ -518,8 +498,7 @@ class AbstractNode(foundations.dataStructures.Structure):
 		self[name] = value
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.NodeAttributeExistsError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.NodeAttributeExistsError)
 	def removeAttribute(self, name):
 		"""
 		This method removes given attribute from the node.
@@ -544,14 +523,13 @@ class AbstractNode(foundations.dataStructures.Structure):
 
 class AbstractCompositeNode(AbstractNode):
 	"""
-	| This class defines the base composite node class.
+	| This class defines the base composite Node class.
 	| It provides compositing capabilities allowing the assembly of graphs and various trees structures.
 	"""
 
 	__family = "AbstractComposite"
 	"""Node family. ( String )"""
 
-	@core.executionTrace
 	def __init__(self, name=None, parent=None, children=None, **kwargs):
 		"""
 		This method initializes the class.
@@ -590,7 +568,7 @@ class AbstractCompositeNode(AbstractNode):
 		return self.__parent
 
 	@parent.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def parent(self, value):
 		"""
 		This method is the setter method for **self.__parent** attribute.
@@ -604,7 +582,7 @@ class AbstractCompositeNode(AbstractNode):
 		self.__parent = value
 
 	@parent.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def parent(self):
 		"""
 		This method is the deleter method for **self.__parent** attribute.
@@ -624,7 +602,7 @@ class AbstractCompositeNode(AbstractNode):
 		return self.__children
 
 	@children.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def children(self, value):
 		"""
 		This method is the setter method for **self.__children** attribute.
@@ -640,7 +618,7 @@ class AbstractCompositeNode(AbstractNode):
 		self.__children = value
 
 	@children.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def children(self):
 		"""
 		This method is the deleter method for **self.__children** attribute.
@@ -652,7 +630,6 @@ class AbstractCompositeNode(AbstractNode):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	# @core.executionTrace
 	def __eq__(self, object):
 		"""
 		This method reimplements the :meth:`AbstractNode.__repr__` method.
@@ -669,8 +646,6 @@ class AbstractCompositeNode(AbstractNode):
 		else:
 			return False
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def child(self, index):
 		"""
 		This method returns the child associated with given index.
@@ -695,8 +670,6 @@ class AbstractCompositeNode(AbstractNode):
 		if index >= 0 and index < len(self.__children):
 			return self.__children[index]
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def indexOf(self, child):
 		"""
 		This method returns the given child index.
@@ -719,11 +692,9 @@ class AbstractCompositeNode(AbstractNode):
 			if child is item:
 				return i
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def row(self):
 		"""
-		This method returns the node row.
+		This method returns the Node row.
 
 		Usage::
 
@@ -741,8 +712,6 @@ class AbstractCompositeNode(AbstractNode):
 		if self.__parent:
 			return self.__parent.indexOf(self)
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def addChild(self, child):
 		"""
 		This method adds given child to the node.
@@ -764,11 +733,9 @@ class AbstractCompositeNode(AbstractNode):
 		child.parent = self
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def removeChild(self, index):
 		"""
-		This method removes child at given index from the node children.
+		This method removes child at given index from the Node children.
 
 		Usage::
 
@@ -791,8 +758,6 @@ class AbstractCompositeNode(AbstractNode):
 		child.parent = None
 		return child
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def insertChild(self, child, index):
 		"""
 		This method inserts given child at given index.
@@ -818,13 +783,11 @@ class AbstractCompositeNode(AbstractNode):
 
 		self.__children.insert(index, child)
 		child.parent = self
-		return True
+		return child
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def hasChildren(self):
 		"""
-		This method returns if the node has children.
+		This method returns if the Node has children.
 
 		Usage::
 
@@ -837,8 +800,6 @@ class AbstractCompositeNode(AbstractNode):
 
 		return True if self.childrenCount() > 0 else False
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def childrenCount(self):
 		"""
 		This method returns the children count.
@@ -856,11 +817,9 @@ class AbstractCompositeNode(AbstractNode):
 
 		return len(self.__children)
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def sortChildren(self, attribute=None, reverseOrder=False):
 		"""
-		This method sorts the children using either the given attribute or the node name.
+		This method sorts the children using either the given attribute or the Node name.
 
 		:param attribute: Attribute name used for sorting. ( String )
 		:param reverseOrder: Sort in reverse order. ( Boolean )
@@ -888,8 +847,6 @@ class AbstractCompositeNode(AbstractNode):
 
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def findChildren(self, pattern=r".*", flags=0, candidates=None):
 		"""
 		This method finds the children matching the given patten.
@@ -917,25 +874,21 @@ class AbstractCompositeNode(AbstractNode):
 			child.findChildren(pattern, flags, candidates)
 		return candidates
 
-	# @core.executionTrace
-	# @foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def findFamily(self, pattern=r".*", flags=0, node=None):
 		"""
-		This method returns the nodes from given family.
+		This method returns the Nodes from given family.
 		
 		:param pattern: Matching pattern. ( String )
 		:param flags: Matching regex flags. ( Integer )
-		:param node: Node to start walking from. (  AbstractNode / AbstractCompositeNode / Object )
+		:param node: Node to start walking from. ( AbstractNode / AbstractCompositeNode / Object )
 		:return: Family nodes. ( List )
 		"""
 
 		return [node for node in foundations.walkers.nodesWalker(node or self) if re.search(pattern, node.family, flags)]
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def listNode(self, tabLevel= -1):
 		"""
-		This method lists the current node and its children.
+		This method lists the current Node and its children.
 
 		Usage::
 
