@@ -42,19 +42,20 @@ __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["RESOURCES_DIRECTORY",
-			"TEST_FILE",
-			"FILE_CONTENT",
-			"FileTestCase",
-			"SetDirectoryTestCase",
-			"CopyTestCase",
-			"RemoveTestCase"]
+		"TEST_FILE",
+		"FILE_CONTENT",
+		"FileTestCase",
+		"SetDirectoryTestCase",
+		"CopyTestCase",
+		"RemoveTestCase"]
 
 RESOURCES_DIRECTORY = os.path.join(os.path.dirname(__file__), "resources")
 TEST_FILE = os.path.join(RESOURCES_DIRECTORY, "loremIpsum.txt")
-FILE_CONTENT = ["Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.\n",
-			"Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.\n",
-			"Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.\n",
-			"Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.\n"]
+FILE_CONTENT = [
+"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.\n",
+"Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.\n",
+"Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.\n",
+"Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.\n"]
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
@@ -69,8 +70,8 @@ class FileTestCase(unittest.TestCase):
 		This method tests presence of required attributes.
 		"""
 
-		requiredAttributes = ("file",
-								"content")
+		requiredAttributes = ("path",
+							"content")
 
 		for attribute in requiredAttributes:
 			self.assertIn(attribute, dir(File))
@@ -80,14 +81,39 @@ class FileTestCase(unittest.TestCase):
 		This method tests presence of required methods.
 		"""
 
-		requiredMethods = ("read",
-							"readAll",
-							"write",
-							"append")
+		requiredMethods = ("cache",
+						"uncache",
+						"read",
+						"write",
+						"append",
+						"clear")
 
 		for method in requiredMethods:
 			self.assertIn(method, dir(File))
 
+	def testCache(self):
+		"""
+		This method tests :meth:`foundations.io.File.cache` method.
+		"""
+
+		ioFile = File(TEST_FILE)
+		self.assertIsInstance(ioFile.content, list)
+		cacheSuccess = ioFile.cache()
+		self.assertTrue(cacheSuccess)
+		self.assertIsInstance(ioFile.content, list)
+		self.assertListEqual(ioFile.content, FILE_CONTENT)
+
+	def testUncache(self):
+		"""
+		This method tests :meth:`foundations.io.File.uncache` method.
+		"""
+
+		ioFile = File(TEST_FILE)
+		ioFile.cache()
+		self.assertListEqual(ioFile.content, FILE_CONTENT)
+		ioFile.uncache()
+		self.assertListEqual(ioFile.content, [])
+
 	def testRead(self):
 		"""
 		This method tests :meth:`foundations.io.File.read` method.
@@ -95,19 +121,7 @@ class FileTestCase(unittest.TestCase):
 
 		ioFile = File(TEST_FILE)
 		self.assertIsInstance(ioFile.content, list)
-		readSuccess = ioFile.read()
-		self.assertTrue(readSuccess)
-		self.assertIsInstance(ioFile.content, list)
-		self.assertListEqual(ioFile.content, FILE_CONTENT)
-
-	def testReadAll(self):
-		"""
-		This method tests :meth:`foundations.io.File.readAll` method.
-		"""
-
-		ioFile = File(TEST_FILE)
-		self.assertIsInstance(ioFile.content, list)
-		content = ioFile.readAll()
+		content = ioFile.read()
 		self.assertIsInstance(ioFile.content, list)
 		self.assertEqual(content, "".join(FILE_CONTENT))
 
@@ -116,29 +130,46 @@ class FileTestCase(unittest.TestCase):
 		This method tests :meth:`foundations.io.File.write` method.
 		"""
 
-		ioFile = File(tempfile.mkstemp()[1])
+		fileDescriptor, path = tempfile.mkstemp()
+		ioFile = File(path)
 		self.assertIsInstance(ioFile.content, list)
 		ioFile.content = FILE_CONTENT
 		writeSuccess = ioFile.write()
 		self.assertTrue(writeSuccess)
-		ioFile.read()
+		ioFile.cache()
 		self.assertListEqual(ioFile.content, FILE_CONTENT)
-		os.remove(ioFile.file)
+		os.close(fileDescriptor)
 
 	def testAppend(self):
 		"""
 		This method tests :meth:`foundations.io.File.append` method.
 		"""
 
-		ioFile = File(tempfile.mkstemp()[1])
+		fileDescriptor, path = tempfile.mkstemp()
+		ioFile = File(path)
 		self.assertIsInstance(ioFile.content, list)
 		ioFile.content = FILE_CONTENT
 		ioFile.write()
 		append = ioFile.append()
 		self.assertTrue(append)
-		ioFile.read()
+		ioFile.cache()
 		self.assertListEqual(ioFile.content, FILE_CONTENT + FILE_CONTENT)
-		os.remove(ioFile.file)
+		os.close(fileDescriptor)
+
+	def testClear(self):
+		"""
+		This method tests :meth:`foundations.io.File.clear` method.
+		"""
+
+		fileDescriptor, path = tempfile.mkstemp()
+		ioFile = File(path)
+		self.assertIsInstance(ioFile.content, list)
+		ioFile.content = FILE_CONTENT
+		ioFile.write()
+		self.assertTrue(ioFile.clear())
+		ioFile.cache()
+		self.assertListEqual(ioFile.content, [])
+		os.close(fileDescriptor)
 
 class SetDirectoryTestCase(unittest.TestCase):
 	"""
