@@ -13,10 +13,10 @@
 **Others:**
 
 """
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
-import logging
 import os
 import re
 import sys
@@ -28,9 +28,8 @@ else:
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.core as core
+import foundations.verbose
 from foundations.io import File
-from foundations.globals.constants import Constants
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -43,20 +42,13 @@ __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["LOGGER",
-		"LOGGING_CONSOLE_HANDLER",
 		"OUTPUT_FILES_EXTENSION",
 		"SLICE_ATTRIBUTE_INDENT",
 		"CONTENT_DELETION",
 		"CONTENT_SUBSTITUTIONS",
 		"sliceDocumentation"]
 
-LOGGER = logging.getLogger(Constants.logger)
-
-LOGGING_CONSOLE_HANDLER = logging.StreamHandler(sys.stdout)
-LOGGING_CONSOLE_HANDLER.setFormatter(core.LOGGING_DEFAULT_FORMATTER)
-LOGGER.addHandler(LOGGING_CONSOLE_HANDLER)
-
-core.setVerbosityLevel(3)
+LOGGER = foundations.verbose.installLogger()
 
 OUTPUT_FILES_EXTENSION = "rst"
 SLICE_ATTRIBUTE_INDENT = 2
@@ -64,6 +56,9 @@ CONTENT_DELETION = ()
 CONTENT_SUBSTITUTIONS = {"resources/": "../",
 						"     \|":"            |" }
 
+foundations.verbose.getLoggingConsoleHandler()
+foundations.verbose.setVerbosityLevel(3)
+
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
@@ -77,7 +72,7 @@ def sliceDocumentation(fileIn, outputDirectory):
 
 	LOGGER.info("{0} | Slicing '{1}' file!".format(sliceDocumentation.__name__, fileIn))
 	file = File(fileIn)
-	file.read()
+	file.cache()
 
 	slices = OrderedDict()
 	for i, line in enumerate(file.content):
@@ -88,7 +83,7 @@ def sliceDocumentation(fileIn, outputDirectory):
 	index = 0
 	for slice, sliceStart in slices.iteritems():
 		sliceFile = File(os.path.join(outputDirectory, "{0}.{1}".format(slice, OUTPUT_FILES_EXTENSION)))
-		LOGGER.info("{0} | Outputing '{1}' file!".format(sliceDocumentation.__name__, sliceFile.file))
+		LOGGER.info("{0} | Outputing '{1}' file!".format(sliceDocumentation.__name__, sliceFile.path))
 		sliceEnd = index < (len(slices.values()) - 1) and slices.values()[index + 1] - SLICE_ATTRIBUTE_INDENT or \
 		len(file.content)
 
